==> haskell-storable-complex-0.2.2-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-storable-complex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-complex
version: 0.2.2
id: storable-complex-0.2.2-Da0akh4asRF37WTCxa2Mpf
key: storable-complex-0.2.2-Da0akh4asRF37WTCxa2Mpf
license: BSD-3-Clause
maintainer: Carter Schonwald <carter.schonwald@gmail.com>
author: Jed Brown <jed@59A2.org>
homepage: https://github.com/cartazio/storable-complex
synopsis: Storable instance for Complex
description:
    Provides a Storable instance for Complex which is binary
    compatible with C99, C++ and Fortran complex data types.
    .
    The only purpose of this package is to provide a standard
    location for this instance so that other packages needing
    this instance can play nicely together.
category: Data
abi: 441e2588ba087131a23f280d70efbf40
exposed: True
exposed-modules:
    Foreign.Storable.Complex
import-dirs: /usr/lib/ghc-8.6.1/site-local/storable-complex-0.2.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/storable-complex-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/storable-complex-0.2.2
hs-libraries: HSstorable-complex-0.2.2-Da0akh4asRF37WTCxa2Mpf
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-storable-complex/html/storable-complex.haddock
haddock-html: /usr/share/doc/haskell-storable-complex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-complex-0.2.3.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-storable-complex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-complex
version: 0.2.3.0
id: storable-complex-0.2.3.0-3wBOLq9SOxQ96iNuDKWiBd
key: storable-complex-0.2.3.0-3wBOLq9SOxQ96iNuDKWiBd
license: BSD-3-Clause
maintainer: Carter Schonwald <carter.schonwald@gmail.com>
author: Jed Brown <jed@59A2.org>
homepage: https://github.com/cartazio/storable-complex
synopsis: Storable instance for Complex
description:
    Provides a Storable instance for Complex which is binary
    compatible with C99, C++ and Fortran complex data types.
    .
    The only purpose of this package is to provide a standard
    location for this instance so that other packages needing
    this instance can play nicely together.
category: Data
abi: b830d863efab72129dce22e62052868b
exposed: True
exposed-modules:
    Foreign.Storable.Complex
import-dirs: /usr/lib/ghc-8.6.2/site-local/storable-complex-0.2.3.0
library-dirs: /usr/lib/ghc-8.6.2/site-local/storable-complex-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/storable-complex-0.2.3.0
hs-libraries: HSstorable-complex-0.2.3.0-3wBOLq9SOxQ96iNuDKWiBd
depends:
    base-4.12.0.0 base-orphans-0.8-I5Wy5X7j4JPBlGRIrsmaA5
haddock-interfaces: /usr/share/doc/haskell-storable-complex/html/storable-complex.haddock
haddock-html: /usr/share/doc/haskell-storable-complex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
